@@ -1,7 +1,6 @@
 /*--------------------------------------------------------------------
- *	$Id: gshhg_version.h 17451 2017-01-16 21:36:06Z pwessel $
  *
- *	Copyright (c) 1991-2017 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -13,7 +12,7 @@
  *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *	GNU Lesser General Public License for more details.
  *
- *	Contact info: gmt.soest.hawaii.edu
+ *	Contact info: www.generic-mapping-tools.org
  *--------------------------------------------------------------------*/
 /*
  * gshhg_version.h contains prototypes
@@ -25,11 +24,11 @@
 
 /*!
  * \file gshhg_version.h
- * \brief 
+ * \brief
  */
 
-#ifndef _GMT_GSHHG_VERSION_H
-#define _GMT_GSHHG_VERSION_H
+#ifndef GMT_GSHHG_VERSION_H
+#define GMT_GSHHG_VERSION_H
 
 #ifdef __cplusplus      /* Basic C++ support */
 extern "C" {
@@ -53,11 +52,10 @@ struct GSHHG_VERSION {
 };
 
 /* Prototypes */
-EXTERN_MSC int gshhg_get_version (const char* filename, struct GSHHG_VERSION *gshhg_version);
 EXTERN_MSC int gshhg_require_min_version (const char* filename, const struct GSHHG_VERSION min_version);
 
 #ifdef __cplusplus
 }
 #endif
 
-#endif  /* _GMT_GSHHG_VERSION_H */
+#endif  /* GMT_GSHHG_VERSION_H */
